@@ -80,7 +80,7 @@ class SwidgetWebsocket:
                             await self.callback(msg)
 
                         elif message.type == aiohttp.WSMsgType.CLOSED:
-                            _LOGGER.warning("AIOHTTP websocket connection closed")
+                            _LOGGER.error("AIOHTTP websocket connection closed")
                             break
 
                         elif message.type == aiohttp.WSMsgType.ERROR:
@@ -107,13 +107,13 @@ class SwidgetWebsocket:
             elif self.state != STATE_STOPPED:
                 retry_delay = min(2 ** (self.failed_attempts - 1) * 30, 300)
                 self.failed_attempts += 1
-                _LOGGER.exception(f"Websocket connection failed, retrying in {retry_delay}s: {error}")
+                _LOGGER.error(f"Websocket connection failed, retrying in {retry_delay}s: {error}")
                 self.state = STATE_DISCONNECTED
                 await asyncio.sleep(retry_delay)
         except Exception as error:  # pylint: disable=broad-except
             _LOGGER.error(f'AIOHTTP Exception')
             if self.state != STATE_STOPPED:
-                _LOGGER.exception(f"Unexpected exception occurred: {error}")
+                _LOGGER.error(f"Unexpected exception occurred: {error}")
                 self._error_reason = ERROR_UNKNOWN
                 self.state = STATE_STOPPED
         else:
@@ -132,6 +132,7 @@ class SwidgetWebsocket:
         self.failed_attempts = 0
         while self.state != STATE_STOPPED:
             await self.running()
+        _LOGGER.error(f"Done Listen")
 
     def close(self):
         """Close the listening websocket."""
